@@ -5,28 +5,30 @@ import logging
 import outdated
 import pandas as pd
 from io import StringIO
+from . import sample
+from urllib3.exceptions import InsecureRequestWarning
 
-__version__ = "0.1.6"
 
 class SolarDB():
 
-    def __init__(self):
-        self.checkIfOutdated()
-        self.__baseURL = "https://solardb.univ-reunion.fr/api/v1/"
-        self.__cookies = None
+    def __init__(self, token: str = None, logging_level: int = 10, apiURL: str = "solardb.univ-reunion.fr", skipSSL: bool = False):
         self.logger = logging.getLogger(__name__)
-        self.setloggerLevel(logging.INFO)
+        self.setLoggerLevel(logging_level)
+        self.checkIfOutdated()
+        self.__baseURL = "https://" + apiURL + "/api/v1/"
+        ## Used to ingore the SSL certification
+        self.__verify = not skipSSL
+        if skipSSL:
+            requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
+        self.__cookies = None
         ## Automatically logs in SolarDB if the token is saved in the '~/.bashrc' file
-        token = os.environ.get('SolarDBToken')
-        if token is not None:
-            self.login(token)
-        else:
-            self.logger.warning("You will need to use your token to log in SolarDB")    
+        if token is None:
+            token = os.environ.get('SolarDBToken')
+        self.login(token)
 
+        ## Methods to log in SolarDB----------------------------------------------------------
 
-    ## Methods to log in SolarDB----------------------------------------------------------
-
-    def login(self, token:str):
+    def login(self, token: str):
         """
         Gives access of SolarDB
 
@@ -49,23 +51,26 @@ class SolarDB():
         """
 
         try:
-            res = requests.get(self.__baseURL + "login?token=" + token)
-            res.raise_for_status()
-            self.__cookies = res.cookies
-            self.logger.debug(json.loads(res.content)["message"])
+            if token is not None:
+                res = requests.get(self.__baseURL + "login?token=" + token, verify=self.__verify)
+                res.raise_for_status()
+                self.__cookies = res.cookies
+                self.logger.debug(json.loads(res.content)["message"])
+            else:
+                self.logger.info("You will need to use your token to log in SolarDB")
         except requests.exceptions.HTTPError:
             self.logger.warning(
-                                "login -> HTTP Error: ",
-                                json.loads(res.content)["message"]
-                                )
+                "login -> HTTP Error: ",
+                json.loads(res.content)["message"]
+            )
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("login -> Connection Error:",errc)
+            self.logger.warning("login -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("login -> Timeout Error:",errt)
+            self.logger.warning("login -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("login -> Request Error: ",err)
+            self.logger.warning("login -> Request Error: ", err)
 
-    def register(self, email:str):
+    def register(self, email: str):
         """
         Sends a token via email.
 
@@ -88,22 +93,26 @@ class SolarDB():
         """
 
         try:
-            res = requests.get(self.__baseURL + "register?email=" + email)
+            res = requests.get(self.__baseURL + "register?email=" + email, verify=self.__verify)
             res.raise_for_status()
             self.logger.debug(json.loads(res.content)["message"])
         except requests.exceptions.HTTPError:
             self.logger.warning("register -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("register -> Connection Error:",errc)
+            self.logger.warning("register -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("register -> Timeout Error:",errt)
+            self.logger.warning("register -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("register -> Request Error: ",err)
+            self.logger.warning("register -> Request Error: ", err)
 
     def status(self):
         """
-        This method is used to verify if you are still logged in. It becomes obsolete if
-        the logging level is higher than INFO.
+        This method is used to verify if you are still logged in.
+
+        Returns
+        -------
+
+        A boolean representing the user's connection status.
 
         Raises
         ------
@@ -119,14 +128,18 @@ class SolarDB():
         """
 
         try:
-            res = requests.get(self.__baseURL + "status", cookies = self.__cookies)
+            logged_in = False
+            res = requests.get(self.__baseURL + "status", cookies=self.__cookies, verify=self.__verify)
+            if json.loads(res.content)["message"] == "User connected":
+                logged_in = True
             self.logger.info(json.loads(res.content)["message"])
+            return logged_in
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("status -> Connection Error:",errc)
+            self.logger.warning("status -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("status -> Timeout Error:",errt)
+            self.logger.warning("status -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("status -> Request Error: ",err)
+            self.logger.warning("status -> Request Error: ", err)
 
     def logout(self):
         """
@@ -146,19 +159,18 @@ class SolarDB():
         """
 
         try:
-            res = requests.get(self.__baseURL + "logout", cookies = self.__cookies)
+            res = requests.get(self.__baseURL + "logout", cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             self.logger.debug(json.loads(res.content)["message"])
             self.__cookies = None
         except requests.exceptions.HTTPError:
             self.logger.warning("logout -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("logout -> Connection Error:",errc)
+            self.logger.warning("logout -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("logout -> Timeout Error:",errt)
+            self.logger.warning("logout -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("logout -> Request Error: ",err)
-
+            self.logger.warning("logout -> Request Error: ", err)
 
     ## Methods to recover the data -------------------------------------------------------
 
@@ -185,7 +197,7 @@ class SolarDB():
 
         sites = []
         try:
-            res = requests.get(self.__baseURL + "data/sites", cookies=self.__cookies)
+            res = requests.get(self.__baseURL + "data/sites", cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             for i in range(len(json.loads(res.content)["data"])):
                 sites.append(json.loads(res.content)["data"][i])
@@ -194,19 +206,19 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getAllSites -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getAllSites -> Connection Error:",errc)
+            self.logger.warning("getAllSites -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getAllSites -> Timeout Error:",errt)
+            self.logger.warning("getAllSites -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getAllSites -> Request Error: ",err)
+            self.logger.warning("getAllSites -> Request Error: ", err)
 
     def getAllTypes(self):
         """
-        Returns all the data types accessible through SolarDB.
+        Returns all the sensor types accessible through SolarDB.
 
         Returns
         -------
-            A list every data type present in SolarDB.
+            A list every sensor type present in SolarDB.
 
         Raises
         ------
@@ -221,33 +233,33 @@ class SolarDB():
             In case an error that is unaccounted for happens
         """
 
-        types = []
+        sensor_types = []
         try:
-            res = requests.get(self.__baseURL + "data/types", cookies=self.__cookies)
+            res = requests.get(self.__baseURL + "data/types", cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             for i in range(len(json.loads(res.content)["data"])):
-                types.append(json.loads(res.content)["data"][i])
+                sensor_types.append(json.loads(res.content)["data"][i])
             self.logger.debug("All data types successfully extracted from SolarDB")
-            return types
+            return sensor_types
         except requests.exceptions.HTTPError:
             self.logger.warning("getAllTypes -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getAllTypes -> Connection Error:",errc)
+            self.logger.warning("getAllTypes -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getAllTypes -> Timeout Error:",errt)
+            self.logger.warning("getAllTypes -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getAllTypes -> Request Error: ",err)
+            self.logger.warning("getAllTypes -> Request Error: ", err)
 
-    def getSensors(self, sites:list[str] = None, types:list[str] = None):
+    def getSensors(self, sites: list = None, sensor_types: list = None):
         """
         Returns sensors present in SolarDB by sites and/or types.
         If no sites or types are given, returns all sensors present in SolarDB
 
         Parameters
         ----------
-        sites : list[str] (OPTIONAL)
+        sites : list (OPTIONAL)
             This list is used to specify the sites in which we will search the sensors.
-        types : list[str] (OPTIONAL)
+        sensor_types : list (OPTIONAL)
             This list is used to specify sensor types to recover.
 
         Returns
@@ -271,12 +283,12 @@ class SolarDB():
         args = ""
         if sites is not None:
             args += "&site=" + ','.join(sites)
-        if types is not None:
-            args += "&type=" + ','.join(types)
+        if sensor_types is not None:
+            args += "&type=" + ','.join(sensor_types)
         if args != "":
             query += "?" + args
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             sensors = json.loads(res.content)["data"]
             self.logger.debug("All sensors successfully extracted from SolarDB")
@@ -284,22 +296,22 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getSensors -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getSensors -> Connection Error:",errc)
+            self.logger.warning("getSensors -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getSensors -> Timeout Error:",errt)
+            self.logger.warning("getSensors -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getSensors -> Request Error: ",err)
+            self.logger.warning("getSensors -> Request Error: ", err)
 
     def getData(
-                self,
-                sites:list[str] = None,
-                types:list[str] = None,
-                sensors:list[str] = None,
-                start:str = None,
-                stop:str = None,
-                aggrFn:str = None,
-                aggrEvery:str = None
-                ):
+            self,
+            sites: list = None,
+            sensor_types: list = None,
+            sensors: list = None,
+            start: str = None,
+            stop: str = None,
+            aggrFn: str = None,
+            aggrEvery: str = None
+    ):
         """
         Extracts data associated to at least one site, sensor and/or type. The user can
         choose the time period on which the extraction is set (set on the last 24h by
@@ -307,11 +319,11 @@ class SolarDB():
 
         Parameters
         ----------
-        sites : list[str]
+        sites : list
             This list is used to specify the sites for which we will search the data.
-        types : list[str]
+        sensor_types : list
             This list is used to specify sensor types used to recover the data.
-        sensors : list[str]
+        sensors : list
             This list is used to specify the sensors used to recover the data.
         start : str (OPTIONAL)
             This string specifies the starting date for the data recovery. It either follows
@@ -366,8 +378,8 @@ class SolarDB():
         args = ""
         if sites is not None:
             args += "&site=" + ','.join(sites)
-        if types is not None:
-            args += "&type=" + ','.join(types)
+        if sensor_types is not None:
+            args += "&type=" + ','.join(sensor_types)
         if sensors is not None:
             args += "&sensorid=" + ','.join(sensors)
         if start is not None:
@@ -382,7 +394,7 @@ class SolarDB():
             query += "?" + args
 
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             data = json.loads(res.content)["data"]
             if data:
@@ -393,29 +405,29 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getData -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getData -> Connection Error:",errc)
+            self.logger.warning("getData -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getData -> Timeout Error:",errt)
+            self.logger.warning("getData -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getData -> Request Error: ",err)
+            self.logger.warning("getData -> Request Error: ", err)
 
     def getBounds(
-                  self,
-                  sites:list[str] = None,
-                  types:list[str] = None,
-                  sensors:list[str] = None
-                  ):
+            self,
+            sites: list = None,
+            sensor_types: list = None,
+            sensors: list = None
+    ):
         """
         Extracts the temporal bounds of each sensor associated to at least one site, sensor
         and/or type.
 
         Parameters
         ----------
-        sites : list[str]
+        sites : list
             This list is used to specify the sites for which we will search the bounds.
-        types : list[str]
-            This list is used to specify sensor types used to recover the bounds.
-        sensors : list[str]
+        sensor_types : list
+            This list is used to specify sensor types used to recover in SolarDB.
+        sensors : list
             This list is used to specify the sensors used to recover the bounds.
 
         Returns
@@ -448,15 +460,15 @@ class SolarDB():
         args = ""
         if sites is not None:
             args += "&site=" + ','.join(sites)
-        if types is not None:
-            args += "&type=" + ','.join(types)
+        if sensor_types is not None:
+            args += "&type=" + ','.join(sensor_types)
         if sensors is not None:
             args += "&sensorid=" + ','.join(sensors)
         if args != "":
             query += "?" + args
-        
+
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             bounds = json.loads(res.content)["data"]
             if bounds:
@@ -467,22 +479,21 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getBounds -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getBounds -> Connection Error:",errc)
+            self.logger.warning("getBounds -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getBounds -> Timeout Error:",errt)
+            self.logger.warning("getBounds -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getBounds -> Request Error: ",err)
-
+            self.logger.warning("getBounds -> Request Error: ", err)
 
     ## Methods to recover the metadata ----------------------------------------------------
-    
+
     def getCampaigns(
-                     self,
-                     ids:str = None,
-                     name:str = None,
-                     territory:str = None,
-                     alias:str = None
-                     ):
+            self,
+            ids: str = None,
+            name: str = None,
+            territory: str = None,
+            alias: str = None
+    ):
         """
         Extracts the different campaigns that took place during the IOS-Net project.
         Specifying the campaign id, name, territory and/or alias will narrow down the
@@ -535,7 +546,7 @@ class SolarDB():
             query += "?" + args
 
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             campaigns = json.loads(res.content)["data"]
             if campaigns:
@@ -546,19 +557,19 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getCampaigns -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getCampaigns -> Connection Error:",errc)
+            self.logger.warning("getCampaigns -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getCampaigns -> Timeout Error:",errt)
+            self.logger.warning("getCampaigns -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getCampaigns -> Request Error: ",err)
+            self.logger.warning("getCampaigns -> Request Error: ", err)
 
     def getInstruments(
-                       self,
-                       ids:str = None,
-                       name:str = None,
-                       label:str = None,
-                       serial:str = None
-                       ):
+            self,
+            ids: str = None,
+            name: str = None,
+            label: str = None,
+            serial: str = None
+    ):
         """
         Returns the different instruments used in the IOS-Net project. Specifying the id,
         name, label and/or serial number will narrow down the instruments recovered.
@@ -608,9 +619,9 @@ class SolarDB():
             args += "&serial=" + serial
         if args != "":
             query += "?" + args
-        
+
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             instruments = json.loads(res.content)["data"]
             if instruments:
@@ -621,19 +632,19 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getInstruments -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getInstruments -> Connection Error:",errc)
+            self.logger.warning("getInstruments -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getInstruments -> Timeout Error:",errt)
+            self.logger.warning("getInstruments -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getInstruments -> Request Error: ",err)
+            self.logger.warning("getInstruments -> Request Error: ", err)
 
     def getMeasures(
-                    self,
-                    ids:str = None,
-                    names:list[str] = None,
-                    dtype:str = None,
-                    nested:bool = None
-                    ):
+            self,
+            ids: str = None,
+            names: list = None,
+            measure_type: str = None,
+            nested: bool = None
+    ):
         """
         Extracts the different measure types used in the IOS-Net project. Specifying the id,
         name and/or data type will narrow down the measures recovered.
@@ -643,10 +654,10 @@ class SolarDB():
         ids : str (OPTIONAL)
             This string is the identity key. It corresponds to the '_id' field in the Mongo
             'measures' collection.
-        names : list[str] (OPTIONAL)
+        names : list (OPTIONAL)
             This corresponds to the sensor/s name/s and is associated to the 'name' field
             in the Mongo 'measures' collection.
-        dtype : list[str] (OPTIONAL)
+        measure_type : list (OPTIONAL)
             This string represents the data type and is associated to the 'type' field in the
             Mongo 'measures' collection.
         nested : bool (OPTIONAL)
@@ -677,15 +688,15 @@ class SolarDB():
             args += "&id=" + ids
         if names is not None:
             args += "&name=" + ','.join(names)
-        if dtype is not None:
-            args += "&type=" + dtype
+        if measure_type is not None:
+            args += "&type=" + measure_type
         if nested is not None:
             args += "&nested=" + str(nested)
         if args != "":
             query += "?" + args
-        
+
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             measures = json.loads(res.content)["data"]
             if measures:
@@ -696,18 +707,18 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getMeasures -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getMeasures -> Connection Error:",errc)
+            self.logger.warning("getMeasures -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getMeasures -> Timeout Error:",errt)
+            self.logger.warning("getMeasures -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getMeasures -> Request Error: ",err)
+            self.logger.warning("getMeasures -> Request Error: ", err)
 
     def getModels(
-                  self,
-                  ids:str = None,
-                  name:str = None,
-                  dtype:str = None
-                  ):
+            self,
+            ids: str = None,
+            name: str = None,
+            model_type: str = None
+    ):
         """
         Returns the models used in the IOS-Net project. Specifying the id, name and/or data
         type will narrow down the models recovered.
@@ -720,7 +731,7 @@ class SolarDB():
         name : str (OPTIONAL)
             This corresponds to the station official name and is associated to the 'name'
             field in the Mongo 'models' collection.
-        dtype : str (OPTIONAL)
+        model_type : str (OPTIONAL)
             This string represents the data type and is associated to the 'type' field in
             the Mongo 'models' collection.
 
@@ -748,13 +759,13 @@ class SolarDB():
             args += "&id=" + ids
         if name is not None:
             args += "&name=" + name
-        if dtype is not None:
-            args += "&type=" + dtype
+        if model_type is not None:
+            args += "&type=" + model_type
         if args != "":
             query += "?" + args
-        
+
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             models = json.loads(res.content)["data"]
             if models:
@@ -765,16 +776,15 @@ class SolarDB():
         except requests.exceptions.HTTPError:
             self.logger.warning("getModels -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getModels -> Connection Error:",errc)
+            self.logger.warning("getModels -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getModels -> Timeout Error:",errt)
+            self.logger.warning("getModels -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getModels -> Request Error: ",err)
-
+            self.logger.warning("getModels -> Request Error: ", err)
 
     ## Utils
 
-    def getSiteDataframe(self, site:str, start:str = None, stop:str = None):
+    def getSiteDataframe(self, site: str, sensor_types: list = None, start: str = None, stop: str = None):
         """
         Extracts a CSV file containing the data associated to a site and converts it into
         a pandas dataframe object. The user can choose the time period on which the extraction
@@ -798,6 +808,8 @@ class SolarDB():
         stop : str (OPTIONAL)
             This string specifies the ending date for the data recovery. It follows the same
             format as "start".
+        sensor_types : list
+            This list is used to specify sensor types to recover in SolarDB.
 
         Returns
         -------
@@ -822,23 +834,26 @@ class SolarDB():
             args += "&start=" + start
         if stop is not None:
             args += "&stop=" + stop
+        if sensor_types is not None:
+            args += "&type=" + ','.join(sensor_types)
         if args != "":
             query += "?" + args
         try:
-            res = requests.get(query, cookies=self.__cookies)
+            res = requests.get(query, cookies=self.__cookies, verify=self.__verify)
             res.raise_for_status()
             df = pd.read_csv(StringIO(res.text))
+            self.logger.debug("pandas dataframe succesfully extracted")
             return df
         except requests.exceptions.HTTPError:
             self.logger.warning("getData -> HTTP Error: ", json.loads(res.content)["message"])
         except requests.exceptions.ConnectionError as errc:
-            self.logger.warning("getData -> Connection Error:",errc)
+            self.logger.warning("getData -> Connection Error:", errc)
         except requests.exceptions.Timeout as errt:
-            self.logger.warning("getData -> Timeout Error:",errt)
+            self.logger.warning("getData -> Timeout Error:", errt)
         except requests.exceptions.RequestException as err:
-            self.logger.warning("getData -> Request Error: ",err)
+            self.logger.warning("getData -> Request Error: ", err)
 
-    def setloggerLevel(self, val:int):
+    def setLoggerLevel(self, val: int):
         """
         Changes the logging level. It is used to enable and/or disable the messages.
         
@@ -869,6 +884,6 @@ class SolarDB():
         """
         Checks if the current version of this package is the latest.
         """
-        is_outdated, latest_version = outdated.check_outdated("pysolardb", __version__)
+        is_outdated, latest_version = outdated.check_outdated("pysolardb", sample.__version__)
         if is_outdated:
-            print("A newer version of the pySolarDB package is currently available: pysolardb ", latest_version)
+            self.logger.warning("A newer version of the pySolarDB package is currently available: pysolardb ", latest_version)
